==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=fon
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Mimamɛ ɔ gblé : yè mɔ nu jɛ  backend wu a kabi mà sɛ wekpa ɖebu doo',
	'avis_echec_syndication_02' => 'Mimamɛ ɔ gblé : mɛ dé siwu yi backend gblogbloji é lɔ tɔn a ',
	'avis_site_introuvable' => 'ye mɔ gblogbloji ɔ a ',
	'avis_site_syndique_probleme' => 'vlɛ ! mima gblogbloji é lɔ tɔn do afɔku ɖe jɛ wɛ ; mi ɖo tè titomɛ ɔ hwɛ. Mi kpɔn guesi gbètakɛn gblogbloji ɔ mimatɔn.(<b>@url_syndic@</b>), bɔ mi  tɛnkpɔn bo bɛ xogbè yɔyɔ ɖevo.', # MODIF
	'avis_sites_probleme_syndication' => 'gblogbloji é lɔ lɛ̂ yé klɛn afɔ ɖé lɛ̂ do mimamɛ',
	'avis_sites_syndiques_probleme' => 'gblogbloji yé  ma é lɔ lɛ̂ yé klɛn afɔ ɖé lɛ̂',

	// B
	'bouton_radio_modere_posteriori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_modere_priori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_non_syndication' => 'mima ɖē tin a ',
	'bouton_radio_syndication' => 'mimamɛ',

	// E
	'entree_adresse_fichier_syndication' => 'gési gbètà tɔn nú nà ɖó bló mimá',
	'entree_adresse_site' => 'gési gblògblòjí ɔ dodo',
	'entree_description_site' => 'tinmɛ gblògblòjí ɔ tɔn ',

	// F
	'form_prop_nom_site' => 'gblogblojí nyíkɔ',

	// I
	'icone_modifier_site' => 'mi vɔ ɖyɔ gblogblojí',
	'icone_referencer_nouveau_site' => 'dó àcɛ gblogblojí ',
	'icone_voir_sites_references' => 'Mi kpɔn gblogblojí yè ná àcɛ ɔ',
	'info_1_site' => 'gblogblojí ɖòkpó',
	'info_a_valider' => '[sɔ kɛn ná]',
	'info_bloquer_lien' => 'mi ján cácádó é lɔ',
	'info_derniere_syndication' => 'Miná gùdó tɔn ɔ',
	'info_liens_syndiques_1' => 'càcàdó mimámɛ',
	'info_liens_syndiques_2' => 'yé bónú yé ní sɔ kɛn ná.',
	'info_nom_site_2' => 'gblogblojí  sín nyíkɔ[dòdò]',
	'info_panne_site_syndique' => 'mimámɛ gblogblojí ɔ tɔn kú àfɔ',
	'info_probleme_grave' => 'xótɛ',
	'info_question_proposer_site' => 'mɛ siwú sɔ gblogblojí yé sɔ kɛn ná sɔ xlɛ ?',
	'info_retablir_lien' => 'Mi lɛ vɔ bló càcàdó ɔ',
	'info_site_attente' => 'E kpò mi ná sɔ kɛn nú gblogblojí ɔ',
	'info_site_propose' => ' Gblogblojí yè sɛɖó ɖò :',
	'info_site_reference' => ' Gblogblojí yé ɖèkúnú ɖò kánú',
	'info_site_refuse' => 'Yè gbɛ gblogblojí ɔ ',
	'info_site_syndique' => 'Yè má gblogblojí ɔ ...', # MODIF
	'info_site_valider' => 'Gblogblojí yè ná sɔ kɛn ná',
	'info_sites_referencer' => 'ɖèkúnú nú gblogblojí ɔ',
	'info_sites_refuses' => 'gblogblojí yé gbɛ lɛ',
	'info_statut_site_1' => 'Gblogblojí é lɔ :',
	'info_statut_site_2' => 'ɖɔdótòjì',
	'info_statut_site_3' => 'sɛɖó',
	'info_statut_site_4' => 'sɔ nyìzùnkɔgbámɛ', # MODIF
	'info_syndication' => 'mìmámɛ :',
	'info_syndication_articles' => 'wěmà lɛ',
	'item_bloquer_liens_syndiques' => 'Mi ján àlɔwlí nú kɛnsísɔ',
	'item_gerer_annuaire_site_web' => 'Tò nyíkɔ lɛ',
	'item_non_bloquer_liens_syndiques' => 'Mi ján àlɔwlí nú kɛnsísɔ',
	'item_non_gerer_annuaire_site_web' => 'Mi mà Tò nyíkɔ lɛ ô',
	'item_non_utiliser_syndication' => 'mi má zán mimámɛ càcà o',
	'item_utiliser_syndication' => 'mi zán xó kléwún lɛ',

	// L
	'lien_mise_a_jour_syndication' => 'mi lɛ vó bló ɖìn',
	'lien_nouvelle_recuperation' => 'mi lɛvɔ jɛ bíblójí',

	// T
	'texte_liens_sites_syndiques' => 'mi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛmi kó mɔ mi àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ ámi lɛ vɔ yí kànjí', # MODIF
	'texte_messages_publics' => 'wɛn wékpá tɔn yé sɔ xlɛ :',
	'texte_non_fonction_referencement' => 'mi hɛn mi ná zán wàlɔ càcàcà ɔ ámi ɖé sú mi bló jɛ xá myɔ  ...', # MODIF
	'texte_referencement_automatique' => 'gbàví ɔ jɛ vɔwɛn é lɔ yé sɛ ɖó ɔ mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúɖò kplékplé yé sɔ ɖó dò wɔ mɛnú àtɛ wô má mì ɔ mi zìn fími ná sɔ mɔ àlì gégéwékpá é lɔxógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔnɔ hɛnmi cyían ɖê jɛ ɖéwú ɔ...).', # MODIF
	'texte_syndication' => 'wékwín é lɔ ɖò wěmámɛyé mɔ wěmà ɖé ɖò gbè é lɔ mɛ áwékwín ɖê yé mà tùn à lɛ ɔ ɖò vɔvɔmɛ. Zìn yé bó kpɔn àyì é yè b ɖó yèwú ɔbló wékwín ɔ ɖómi kpɔn winwlán fɔ ɖìɖéBɛ wékwín sín wěmámɛVlɛ mi klɛn àfɔ súkpɔ ɖò wěmà mi tɔn mɛ Mi jɛ wěmà lɛ blóɖó jí nú mi má wá wàzɔ gɔná óMi sɔ càvì ɖévóklɛn àfɔ ɖò fí ámi sɔ yí gblogblo é lɔ jí áyé hùn fí nú mɛ bí ámi byɔ ɖɔ é mi ná ɖɔ xó ɖò kplékplé ɔ mɛmi sɔ e-mailú mi tɔn xlɛ Wɛn é lɔ wɛn càcà wɛ Nú mi ná ɖó mɔ nɔtɛn gblogblojí  é lɔ tɔn  mi yìwàlɔ bìbɛ tɔnsɔ ɖémɛ ɖê ɖé gbɔn ɔ gbètá ɔ kló ɖín', # MODIF
	'titre_articles_syndiques' => 'wékpá ɖê yé má sín gblogblo é lɔ jí',
	'titre_dernier_article_syndique' => 'wékpá gùdó tɔn ê má ɔ',
	'titre_page_sites_tous' => 'gblogblojí yé ɖó àcɛ ná',
	'titre_referencement_sites' => 'àcɛ yíyí ɖò gblogblojí kpó mìmámɛ',
	'titre_site_numero' => 'númɛló gblogblojí ɔ tɔn :',
	'titre_sites_proposes' => 'gblogblojí yé sɛ ɖó',
	'titre_sites_references_rubrique' => 'gblogblojí yé ná àcɛ ná ɖò àkpáxwé é lɔ',
	'titre_sites_syndiques' => 'gblogblojí yé má',
	'titre_sites_tous' => 'gblogblojí yé ná àcɛ ná ',
	'titre_syndication' => ' Mímá ɔ Gblogblojí tɔn'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Mimamɛ ɔ gblé : yè mɔ nu jɛ  backend wu a kabi mà sɛ wekpa ɖebu doo',
	'avis_echec_syndication_02' => 'Mimamɛ ɔ gblé : mɛ dé siwu yi backend gblogbloji é lɔ tɔn a ',
	'avis_site_introuvable' => 'ye mɔ gblogbloji ɔ a ',
	'avis_site_syndique_probleme' => 'vlɛ ! mima gblogbloji é lɔ tɔn do afɔku ɖe jɛ wɛ ; mi ɖo tè titomɛ ɔ hwɛ. Mi kpɔn guesi gbètakɛn gblogbloji ɔ mimatɔn.(<b>@url_syndic@</b>), bɔ mi  tɛnkpɔn bo bɛ xogbè yɔyɔ ɖevo.', # MODIF
	'avis_sites_probleme_syndication' => 'gblogbloji é lɔ lɛ̂ yé klɛn afɔ ɖé lɛ̂ do mimamɛ',
	'avis_sites_syndiques_probleme' => 'gblogbloji yé  ma é lɔ lɛ̂ yé klɛn afɔ ɖé lɛ̂',

	// B
	'bouton_radio_modere_posteriori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_modere_priori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_non_syndication' => 'mima ɖē tin a ',
	'bouton_radio_syndication' => 'mimamɛ',

	// E
	'entree_adresse_fichier_syndication' => 'gési gbètà tɔn nú nà ɖó bló mimá',
	'entree_adresse_site' => 'gési gblògblòjí ɔ dodo',
	'entree_description_site' => 'tinmɛ gblògblòjí ɔ tɔn ',

	// F
	'form_prop_nom_site' => 'gblogblojí nyíkɔ',

	// I
	'icone_modifier_site' => 'mi vɔ ɖyɔ gblogblojí',
	'icone_referencer_nouveau_site' => 'dó àcɛ gblogblojí ',
	'icone_voir_sites_references' => 'Mi kpɔn gblogblojí yè ná àcɛ ɔ',
	'info_1_site' => 'gblogblojí ɖòkpó',
	'info_a_valider' => '[sɔ kɛn ná]',
	'info_bloquer_lien' => 'mi ján cácádó é lɔ',
	'info_derniere_syndication' => 'Miná gùdó tɔn ɔ',
	'info_liens_syndiques_1' => 'càcàdó mimámɛ',
	'info_liens_syndiques_2' => 'yé bónú yé ní sɔ kɛn ná.',
	'info_nom_site_2' => 'gblogblojí  sín nyíkɔ[dòdò]',
	'info_panne_site_syndique' => 'mimámɛ gblogblojí ɔ tɔn kú àfɔ',
	'info_probleme_grave' => 'xótɛ',
	'info_question_proposer_site' => 'mɛ siwú sɔ gblogblojí yé sɔ kɛn ná sɔ xlɛ ?',
	'info_retablir_lien' => 'Mi lɛ vɔ bló càcàdó ɔ',
	'info_site_attente' => 'E kpò mi ná sɔ kɛn nú gblogblojí ɔ',
	'info_site_propose' => ' Gblogblojí yè sɛɖó ɖò :',
	'info_site_reference' => ' Gblogblojí yé ɖèkúnú ɖò kánú',
	'info_site_refuse' => 'Yè gbɛ gblogblojí ɔ ',
	'info_site_syndique' => 'Yè má gblogblojí ɔ ...', # MODIF
	'info_site_valider' => 'Gblogblojí yè ná sɔ kɛn ná',
	'info_sites_referencer' => 'ɖèkúnú nú gblogblojí ɔ',
	'info_sites_refuses' => 'gblogblojí yé gbɛ lɛ',
	'info_statut_site_1' => 'Gblogblojí é lɔ :',
	'info_statut_site_2' => 'ɖɔdótòjì',
	'info_statut_site_3' => 'sɛɖó',
	'info_statut_site_4' => 'sɔ nyìzùnkɔgbámɛ', # MODIF
	'info_syndication' => 'mìmámɛ :',
	'info_syndication_articles' => 'wěmà lɛ',
	'item_bloquer_liens_syndiques' => 'Mi ján àlɔwlí nú kɛnsísɔ',
	'item_gerer_annuaire_site_web' => 'Tò nyíkɔ lɛ',
	'item_non_bloquer_liens_syndiques' => 'Mi ján àlɔwlí nú kɛnsísɔ',
	'item_non_gerer_annuaire_site_web' => 'Mi mà Tò nyíkɔ lɛ ô',
	'item_non_utiliser_syndication' => 'mi má zán mimámɛ càcà o',
	'item_utiliser_syndication' => 'mi zán xó kléwún lɛ',

	// L
	'lien_mise_a_jour_syndication' => 'mi lɛ vó bló ɖìn',
	'lien_nouvelle_recuperation' => 'mi lɛvɔ jɛ bíblójí',

	// T
	'texte_liens_sites_syndiques' => 'mi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛmi kó mɔ mi àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ ámi lɛ vɔ yí kànjí', # MODIF
	'texte_messages_publics' => 'wɛn wékpá tɔn yé sɔ xlɛ :',
	'texte_non_fonction_referencement' => 'mi hɛn mi ná zán wàlɔ càcàcà ɔ ámi ɖé sú mi bló jɛ xá myɔ  ...', # MODIF
	'texte_referencement_automatique' => 'gbàví ɔ jɛ vɔwɛn é lɔ yé sɛ ɖó ɔ mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúɖò kplékplé yé sɔ ɖó dò wɔ mɛnú àtɛ wô má mì ɔ mi zìn fími ná sɔ mɔ àlì gégéwékpá é lɔxógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔnɔ hɛnmi cyían ɖê jɛ ɖéwú ɔ...).', # MODIF
	'texte_syndication' => 'wékwín é lɔ ɖò wěmámɛyé mɔ wěmà ɖé ɖò gbè é lɔ mɛ áwékwín ɖê yé mà tùn à lɛ ɔ ɖò vɔvɔmɛ. Zìn yé bó kpɔn àyì é yè b ɖó yèwú ɔbló wékwín ɔ ɖómi kpɔn winwlán fɔ ɖìɖéBɛ wékwín sín wěmámɛVlɛ mi klɛn àfɔ súkpɔ ɖò wěmà mi tɔn mɛ Mi jɛ wěmà lɛ blóɖó jí nú mi má wá wàzɔ gɔná óMi sɔ càvì ɖévóklɛn àfɔ ɖò fí ámi sɔ yí gblogblo é lɔ jí áyé hùn fí nú mɛ bí ámi byɔ ɖɔ é mi ná ɖɔ xó ɖò kplékplé ɔ mɛmi sɔ e-mailú mi tɔn xlɛ Wɛn é lɔ wɛn càcà wɛ Nú mi ná ɖó mɔ nɔtɛn gblogblojí  é lɔ tɔn  mi yìwàlɔ bìbɛ tɔnsɔ ɖémɛ ɖê ɖé gbɔn ɔ gbètá ɔ kló ɖín', # MODIF
	'titre_articles_syndiques' => 'wékpá ɖê yé má sín gblogblo é lɔ jí',
	'titre_dernier_article_syndique' => 'wékpá gùdó tɔn ê má ɔ',
	'titre_page_sites_tous' => 'gblogblojí yé ɖó àcɛ ná',
	'titre_referencement_sites' => 'àcɛ yíyí ɖò gblogblojí kpó mìmámɛ',
	'titre_site_numero' => 'númɛló gblogblojí ɔ tɔn :',
	'titre_sites_proposes' => 'gblogblojí yé sɛ ɖó',
	'titre_sites_references_rubrique' => 'gblogblojí yé ná àcɛ ná ɖò àkpáxwé é lɔ',
	'titre_sites_syndiques' => 'gblogblojí yé má',
	'titre_sites_tous' => 'gblogblojí yé ná àcɛ ná ',
	'titre_syndication' => ' Mímá ɔ Gblogblojí tɔn',
];
